You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@airavata.apache.org by sa...@apache.org on 2012/12/19 17:53:20 UTC

svn commit: r1423943 - in /airavata/trunk/modules/airavata-client/src/main/java/org/apache/airavata/client: api/ExperimentAdvanceOptions.java impl/AiravataManagerImpl.java

Author: samindaw
Date: Wed Dec 19 16:53:20 2012
New Revision: 1423943

URL: http://svn.apache.org/viewvc?rev=1423943&view=rev
Log:
adding ExperimentAdvanceOptions interface etc.

Modified:
    airavata/trunk/modules/airavata-client/src/main/java/org/apache/airavata/client/api/ExperimentAdvanceOptions.java
    airavata/trunk/modules/airavata-client/src/main/java/org/apache/airavata/client/impl/AiravataManagerImpl.java

Modified: airavata/trunk/modules/airavata-client/src/main/java/org/apache/airavata/client/api/ExperimentAdvanceOptions.java
URL: http://svn.apache.org/viewvc/airavata/trunk/modules/airavata-client/src/main/java/org/apache/airavata/client/api/ExperimentAdvanceOptions.java?rev=1423943&r1=1423942&r2=1423943&view=diff
==============================================================================
--- airavata/trunk/modules/airavata-client/src/main/java/org/apache/airavata/client/impl/AiravataManagerImpl.java (original)
+++ airavata/trunk/modules/airavata-client/src/main/java/org/apache/airavata/client/impl/AiravataManagerImpl.java Wed Dec 19 16:53:20 2012
@@ -30,13 +30,8 @@ import java.util.List;
 import org.apache.airavata.client.AiravataClient;
 import org.apache.airavata.client.api.AiravataAPIInvocationException;
 import org.apache.airavata.client.api.AiravataManager;
-import org.apache.airavata.common.exception.AiravataConfigurationException;
 import org.apache.airavata.registry.api.AiravataUser;
 import org.apache.airavata.registry.api.Gateway;
-import org.apache.airavata.registry.api.exception.RegistryAccessorInstantiateException;
-import org.apache.airavata.registry.api.exception.RegistryAccessorInvalidException;
-import org.apache.airavata.registry.api.exception.RegistryAccessorNotFoundException;
-import org.apache.airavata.registry.api.exception.RegistryAccessorUndefinedException;
 
 public class AiravataManagerImpl implements AiravataManager {
 	private AiravataClient client;
--- airavata/trunk/modules/airavata-client/src/main/java/org/apache/airavata/client/api/ExperimentAdvanceOptions.java (original)
+++ airavata/trunk/modules/airavata-client/src/main/java/org/apache/airavata/client/api/ExperimentAdvanceOptions.java Wed Dec 19 16:53:20 2012
@@ -27,81 +27,87 @@ public interface ExperimentAdvanceOption
 	
 	/**
 	 * Get the user who will be running the experiment if different from the experiment
-	 * submitting user
-	 * @return
+	 * submitting user.
+	 * @return String representing the execution user
 	 */
 	public String getExperimentExecutionUser();
 	
 	/**
-	 * Get the metadata for the experiment
-	 * @return
+	 * Get the metadata for the experiment.
+	 * @return String representing the custom metadata.
 	 */
 	public String getExperimentMetadata();
 	
 	/**
 	 * Get the name of the experiment
-	 * @return
+	 * @return String representing the experiment name.
 	 */
 	public String getExperimentName();
 	
 	/**
-	 * Get the custom Id that will be used as the experiment Id
-	 * @return
+	 * Get the custom Id that will be used as the experiment Id.
+	 * @return String representing the custom experiment Id.
 	 */
 	public String getCustomExperimentId();
 	
 	/**
-	 * Get the custom workflow context settings
-	 * @return
+	 * Get the custom workflow context settings.
+	 * @return WorkflowContextHeaderBuilder object.
 	 */
 	public WorkflowContextHeaderBuilder getCustomWorkflowContext();
 	
 	/**
 	 * Set a 3rd party user identity as the user who performed this experiment. If not specified 
-	 * the experiment submission user will be used as the execution user 
+	 * the experiment submission user will be used as the execution user.
+	 * @param experimentExecutionUser - String representing the user.
 	 */
 	public void setExperimentExecutioUser(String experimentExecutionUser);
 	
 	/**
 	 * Set custom metadata for the experiment. 
 	 * Note: Users can store custom data related to experiment along with the experiment and 
 	 * retrieve them later on 
 	 */
-	public void setExperimentCustomMetadata();
+	public void setExperimentCustomMetadata(String experimentMetadata);
 	
 	/**
 	 * Set the name of the experiment. Must be unique. If not defined the name will be 
-	 * auto-generated using the worklfow template Id & & time of experiment submission 
+	 * auto-generated using the worklfow template Id & & time of experiment submission .
+	 * @param experimentName - String representing experiment name.
 	 */
-	public void setExperimentName();
+	public void setExperimentName(String experimentName);
 	
 	/**
 	 * Set a custom id as an experiment Id. If not specified the system will autogenerate an 
-	 * experiment id
+	 * experiment id.
+	 * @param customExperimentId - String representing the experiment Id.
 	 */
-	public void setCustomExperimentId();
+	public void setCustomExperimentId(String customExperimentId);
 	
 	/**
 	 * Set a custom workflow context to the experiment. From this users can specify scheduling,
 	 * output handling & security related custom settings. If not specified a default empty workflow
 	 * context will be used.
-	 * @param builder
+	 * @param workflowContext - WorkflowContextHeaderBuilder object which contains the custom 
+	 * settings for the workflow context.
 	 */
-	public void setCustomWorkflowContext(WorkflowContextHeaderBuilder builder);
+	public void setCustomWorkflowContext(WorkflowContextHeaderBuilder workflowContext);
 	
 	/**
-	 * Create a new Workflow Context object. 
-	 * Note: This will not be set it as the Custom Workflow Context in the ExperimentAdanceOptions. 
-	 * Users should use <code>setCustomWorkflowContext</code> function to do so.
-	 * @return
+	 * Create a new Workflow Context object. <br />
+	 * <i><b>Note:</b> This will not be set as the Custom Workflow Context in the ExperimentAdanceOptions. 
+	 * Users should use the function </i><code><b>setCustomWorkflowContext(...)</b></code><i> to do 
+	 * so</i>.
+	 * @return A WorkflowContextHeaderBuilder object.
 	 */
 	public WorkflowContextHeaderBuilder newCustomWorkflowContext();
 	
 	/**
-	 * Create a unique experiment Id. 
-	 * Note: This will not be set as the experiment Id for the experiment. Users should use
-	 * <code>setCustomExperimentId</code> function to do so.
-	 * @return
+	 * Create a unique experiment Id.<br />
+	 * <i><b>Note:</b> This will not be set as the experiment Id for the experiment. Users should use the
+	 * function </i><code><b>setCustomExperimentId(...)</b></code><i> to do so.
+	 * @return A string representing a unique id.
 	 */
 	public String generatExperimentId();
 }
@@ -27,81 +27,87 @@ public interface ExperimentAdvanceOption
 	
 	/**
-	 * Set custom metadata for the experiment. 
-	 * Note: Users can store custom data related to experiment along with the experiment and 
-	 * retrieve them later on 
+	 * Set custom metadata for the experiment.<br />
+	 * <i><b>Note:</b> Users can store custom data related to experiment along with the experiment and 
+	 * retrieve them later on.</i> 
+	 * @param experimentMetadata - String representing the metadata.
 	 */

Modified: airavata/trunk/modules/airavata-client/src/main/java/org/apache/airavata/client/impl/AiravataManagerImpl.java
URL: http://svn.apache.org/viewvc/airavata/trunk/modules/airavata-client/src/main/java/org/apache/airavata/client/impl/AiravataManagerImpl.java?rev=1423943&r1=1423942&r2=1423943&view=diff
==============================================================================